pub struct Gopher { /* private fields */ }Expand description
The Gopher struct represents an initialized object ready to connect.
Implementations
Sourceimpl Gopher
impl Gopher
Sourcepub fn new(endpoint: &str) -> Result<Self, GopherError>
pub fn new(endpoint: &str) -> Result<Self, GopherError>
Create a new Gopher object with the given endpoint.
Example
use gophers::Gopher;
let gopher = Gopher::new("gophers://bitreich.org").unwrap();Sourcepub fn connect(&self) -> Result<GopherConnection, GopherError>
pub fn connect(&self) -> Result<GopherConnection, GopherError>
Establish a connection with a created Gopher object.
Depending on tls, it will establish either a plain TCP or an
encrypted TLS connection.
Example
use gophers::Gopher;
let gopher = Gopher::new("gophers://bitreich.org").unwrap();
let mut stream = gopher.connect().unwrap();Auto Trait Implementations
impl Freeze for Gopher
impl RefUnwindSafe for Gopher
impl Send for Gopher
impl Sync for Gopher
impl Unpin for Gopher
impl UnsafeUnpin for Gopher
impl UnwindSafe for Gopher